==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/zh_CN.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "标签",
    "Update" : "更新",
    "Create" : "创建",
    "Select tag…" : "选择标签...",
    "Tagged files" : "标签文件",
    "Select tags to filter by" : "选择标签来筛选",
    "No tags found" : "标签未找到",
    "Please select tags to filter by" : "请选择标签来筛选",
    "No files found for the selected tags" : "该标签下没有任何文件",
    "Added system tag {systemtag}" : "已添加系统标签 {systemtag}",
    "Added system tag %1$s" : "已添加的系统标签 %1$s",
    "%1$s added system tag %2$s" : "%1$s 已添加的系统标签 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已添加的系统标签 {systemtag}",
    "Removed system tag {systemtag}" : "已移除的系统标签 {systemtag}",
    "Removed system tag %1$s" : "已移除的系统标签 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You created system tag %1$s" : "您创建了系统标签 %1$s",
    "You created system tag {systemtag}" : "您创建了系统标签 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 创建了系统标签 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 创建了系统标签 {systemtag}",
    "You deleted system tag %1$s" : "您删除了系统标签 %1$s",
    "You deleted system tag {systemtag}" : "您删除了系统标签 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您已经将系统标签 %2$s 更新为 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 已经将系统标签 %3$s 更新为 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "You added system tag %2$s to %1$s" : "您为 %1$s 填加了系统标签 %2$s",
    "You added system tag {systemtag} to {file}" : "您为 {file} 添加了系统标签 {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 为 %2$s 添加了系统标签 %3$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 为 {file} 添加了系统标签 {systemtag}",
    "You removed system tag %2$s from %1$s" : "您从 %1$s 移除了系统标签 %2$s",
    "You removed system tag {systemtag} from {file}" : "您从 {file} 移除了系统标签 {systemtag}.",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 从 %2$s 移除了系统标签 %3$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 从 {file} 中移除了系统标签 {systemtag}",
    "%s (restricted)" : "%s (受限)",
    "%s (invisible)" : "%s (不可见)",
    "<strong>System tags</strong> for a file have been modified" : "已更改的文件的<strong>系统标签</strong> ",
    "Collaborative tags" : "协同标签",
    "Select tag …" : "选择标签...",
    "Name" : "名称",
    "Public" : "公开",
    "Restricted" : "受限",
    "Invisible" : "不可见",
    "Delete" : "删除",
    "Reset" : "重置",
    "No files in here" : "无文件",
    "No entries found in this folder" : "此文件夹中无项目",
    "Size" : "大小",
    "Modified" : "修改日期",
    "Create and edit collaborative tags. These tags affect all users." : "创建并编辑协同标签. 这些标签影响全部用户."
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/zh_CN.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "标签",
    "Update" : "更新",
    "Create" : "创建",
    "Select tag…" : "选择标签...",
    "Tagged files" : "标签文件",
    "Select tags to filter by" : "选择标签来筛选",
    "No tags found" : "标签未找到",
    "Please select tags to filter by" : "请选择标签来筛选",
    "No files found for the selected tags" : "该标签下没有任何文件",
    "Added system tag {systemtag}" : "已添加系统标签 {systemtag}",
    "Added system tag %1$s" : "已添加的系统标签 %1$s",
    "%1$s added system tag %2$s" : "%1$s 已添加的系统标签 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已添加的系统标签 {systemtag}",
    "Removed system tag {systemtag}" : "已移除的系统标签 {systemtag}",
    "Removed system tag %1$s" : "已移除的系统标签 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You created system tag %1$s" : "您创建了系统标签 %1$s",
    "You created system tag {systemtag}" : "您创建了系统标签 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 创建了系统标签 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 创建了系统标签 {systemtag}",
    "You deleted system tag %1$s" : "您删除了系统标签 %1$s",
    "You deleted system tag {systemtag}" : "您删除了系统标签 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您已经将系统标签 %2$s 更新为 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 已经将系统标签 %3$s 更新为 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "You added system tag %2$s to %1$s" : "您为 %1$s 填加了系统标签 %2$s",
    "You added system tag {systemtag} to {file}" : "您为 {file} 添加了系统标签 {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 为 %2$s 添加了系统标签 %3$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 为 {file} 添加了系统标签 {systemtag}",
    "You removed system tag %2$s from %1$s" : "您从 %1$s 移除了系统标签 %2$s",
    "You removed system tag {systemtag} from {file}" : "您从 {file} 移除了系统标签 {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 从 %2$s 移除了系统标签 %3$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 从 {file} 中移除了系统标签 {systemtag}",
    "%s (restricted)" : "%s（受限）",
    "%s (invisible)" : "%s（不可见）",
    "<strong>System tags</strong> for a file have been modified" : "已更改的文件的<strong>系统标签</strong> ",
    "Collaborative tags" : "协同标签",
    "Select tag …" : "选择标签...",
    "Name" : "名称",
    "Public" : "公开",
    "Restricted" : "受限",
    "Invisible" : "不可见",
    "Delete" : "删除",
    "Reset" : "重置",
    "No files in here" : "无文件",
    "No entries found in this folder" : "此文件夹中无项目",
    "Size" : "大小",
    "Modified" : "修改日期",
    "Create and edit collaborative tags. These tags affect all users." : "创建并编辑协同标签。这些标签影响全部用户。"
},
"nplurals=1; plural=0;");
